package widebase.rpc.table

import widebase.util.SysProps

/** Scope properties.
 *
 * Set directly or by system properties.
 *
 * Global property keys:
 * {{{
 * widebase.io. { filter }
 * }}}
 *
 * Package property keys:
 * {{{
 * widebase.rpc.table { filter }
 * }}}
 *
 * Individual property keys:
 * {{{
 * widebase.rpc.table { filters._ }
 * }}}
 *
 * @author myst3r10n
 */
object Props extends PropsLike {

  import vario.filter.StreamFilter.StreamFilter

  /** This package name. */
  override protected val packageName = "widebase.rpc.table"

  /** Stream filter properties.
   *
   * @author myst3r10n
   */
  object filters {

    /** Used stream filter to deserialize tables. */
    var deserialize: StreamFilter = _

    /** Used stream filter to serialize tables. */
    var serialize: StreamFilter = _

    reset

    /** Resets stream filter properties. */
    def reset {

      deserialize =
        SysProps.getFilter(packageName + ".filters.deserialize", defaultFilter)

      serialize =
        SysProps.getFilter(packageName + ".filters.serialize", defaultFilter)

    }
  }
}

