package widebase.rpc.table

import widebase.rpc.interface.ClientInterface

/** Finds tables within remote database.
 *
 * @param proxy to client interface
 * @param authId of client
 *
 * @author myst3r10n
 */
class RemoteTableFind(proxy: ClientInterface, authId: String) {

  /** Checks whether remote table exists.
    *
    * @param name of table
    * @param segmented name of segment
    *
    * @return true if exists, else false
   */
  def apply(name: String)(implicit segmented: String = null) =
    proxy.find(authId, name)(segmented)

  /** Checks whether remote directory table exists.
    *
    * @note Supports optional partitioned and segmented tables.
    *
    * @param name of table
    * @param parted partition name
    * @param segmented name of segment
    *
    * @return true if exists, else false
   */
  def dir(name: String)
    (implicit parted: String = null, segmented: String = null) = {

    val partition: String =
      if(parted == null)
        ""
      else
        parted

    proxy.findDir(authId, name)(partition, segmented)

  }
}

