package widebase.rpc.table

import widebase.db.table.Table
import widebase.rpc.interface.ClientInterface

/** Saves tables into database.
 *
 * @param proxy to client interface
 * @param authId of client
 *
 * @author myst3r10n
 */
class RemoteTableSave(proxy: ClientInterface, authId: String) {

  import vario.filter.StreamFilter.StreamFilter

  /** Saves table into remote database.
    *
    * @param name of table
    * @param table self-explanatory
    * @param filter self-explanatory
    * @param segmented segment key
   */
  def apply(
    name: String,
    table: Table,
    filter: StreamFilter = props.filters.serialize)
    (implicit segmented: String = null) {

    proxy.save(authId, name, table.toBytes(filter))(segmented)

  }

  /** Saves table into remote directory table.
    *
    * @note Supports optional partitioned or segmented tables.
    *
    * @param name of table
    * @param table self-explanatory
    * @param filter self-explanatory
    * @param parted partition symbol
    * @param segmented segment key
   */
  def dir(
    name: String,
    table: Table,
    filter: StreamFilter = props.filters.serialize)
    (implicit parted: Symbol = null, segmented: String = null) {

    val partition: String =
      if(parted == null)
        ""
      else
        parted.toString.drop(1)

    proxy.saveDir(authId, name, table.toBytes(filter))(partition, segmented)

  }
}

